@@ -1,7 +1,7 @@
 import os, sys  
 import sqlite3 
 
-__version__ = version = '2.1.7'
+__version__ = version = '2.1.7.1'
 
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;,._||" + r'"' + r"'<>?/0123456789"
 INSERT_SPECIAL_CHARS = r"0123456789" + r"-_()[]:/.,@#&" 
@@ -24,6 +24,7 @@ def __selroutine():
     Wordlists = {item[0] : item[1] for item in Wordlists}
  
 if 'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' in os.environ:
+    print("Underprocess")
     Wordlists = {}
     
 else:
